@@ -24,7 +24,6 @@ class QueueExistsWaiter extends Waiter
             return self::STATE_PENDING;
         }
 
-        /** @psalm-suppress TypeDoesNotContainType */
         return null === $exception ? self::STATE_PENDING : self::STATE_FAILURE;
     }
 
@@ -37,6 +36,6 @@ class QueueExistsWaiter extends Waiter
             throw new InvalidArgument('missing last request injected in waiter result');
         }
 
-        return $this->awsClient->QueueExists($this->input);
+        return $this->awsClient->queueExists($this->input);
     }
 }
